{% extends "base.html" %}
{% load i18n %}

{% block page_title %}{% trans "Authority List" %}{% endblock %}
{% block content %}

<ul>
{% for a in authorities %}
    <li>{{ a }} 
        <a href='{% url "authority_view" a.id %}'>{% trans "View" %}</a>
        <a href='{% url "authority_update" a.id %}'>{% trans "Edit" %}</a>
        <a href='{% url "authority_update_users" a.id %}'>{% trans "Edit users" %}</a>
    </li>
{% empty %}
    <li>{% trans "No authorities" %}</li>
{% endfor %}
</ul>
<a href='{% url "authority_create" %}'>{% trans "Create" %}</a>
{% endblock %}