{% extends "base.html" %}
{% load i18n %}

{% block page_title %}{% trans "Authority form" %}{% endblock %}

{% block content %}
<form method='POST'>
    {% csrf_token %}
    {{ form }}
    <input type='submit' value='{% trans "Submit" %}' />
</form>
{% endblock %}