# Generated by Django 3.0.3 on 2020-02-24 11:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('authorities', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='authority',
            name='name',
            field=models.CharField(max_length=255, unique=True, verbose_name='Name'),
        ),
        migrations.AlterField(
            model_name='authoritykind',
            name='name',
            field=models.CharField(max_length=255, unique=True, verbose_name='Name'),
        ),
    ]
